Library providing data structures and functions supporting the execution
and management of DLC.
Modules
- Implementation of a chain monitor to watch the blockchain for transactions of interest.
- Module containing structures and methods for working with DLC channels.
- This module contains static functions to update the state of a DLC channel.
- Module containing structures and functions related to contracts.
- This module contains static functions to update the state of a DLC.
- #Error
- #Manager a component to create and update DLCs.
- #PayoutFunction
Structs
- A ContractSignerProvider that caches the signers
- Simple sample implementation of
ContractSigner. - Provide current time through
SystemTime. - Represents a UTXO.
Traits
- Blockchain trait provides access to the bitcoin blockchain.
- Provides signing related functionalities.
- Oracle trait provides access to oracle information.
- Storage trait provides functionalities to store and retrieve DLCs.
- Time trait to provide current unix time. Mainly defined to facilitate testing.
- Wallet trait to provide functionalities related to generating, storing and managing bitcoin addresses and UTXOs.
Type Aliases
- Type alias for a channel id.
- Type alias for a contract id.
- Type alias for a keys id.